pub struct SectionAttributes(/* private fields */);Expand description
The SectionAttributes flag value.
Implementations
Sourceimpl SectionAttributes
impl SectionAttributes
Sourcepub const PURE_INSTRUCTIONS: SectionAttributes
pub const PURE_INSTRUCTIONS: SectionAttributes
The PURE_INSTRUCTIONS flag value.
Sourcepub const NO_TOC: SectionAttributes
pub const NO_TOC: SectionAttributes
The NO_TOC flag value.
Sourcepub const STRIP_STATIC_SYMS: SectionAttributes
pub const STRIP_STATIC_SYMS: SectionAttributes
The STRIP_STATIC_SYMS flag value.
Sourcepub const NO_DEAD_STRIP: SectionAttributes
pub const NO_DEAD_STRIP: SectionAttributes
The NO_DEAD_STRIP flag value.
Sourcepub const LIVE_SUPPORT: SectionAttributes
pub const LIVE_SUPPORT: SectionAttributes
The LIVE_SUPPORT flag value.
Sourcepub const SELF_MODIFYING_CODE: SectionAttributes
pub const SELF_MODIFYING_CODE: SectionAttributes
The SELF_MODIFYING_CODE flag value.
Sourcepub const DEBUG: SectionAttributes
pub const DEBUG: SectionAttributes
The DEBUG flag value.
Sourcepub const SOME_INSTRUCTIONS: SectionAttributes
pub const SOME_INSTRUCTIONS: SectionAttributes
The SOME_INSTRUCTIONS flag value.
Sourcepub const EXT_RELOC: SectionAttributes
pub const EXT_RELOC: SectionAttributes
The EXT_RELOC flag value.
Sourcepub const LOC_RELOC: SectionAttributes
pub const LOC_RELOC: SectionAttributes
The LOC_RELOC flag value.
Sourceimpl SectionAttributes
impl SectionAttributes
Sourcepub const fn empty() -> SectionAttributes
pub const fn empty() -> SectionAttributes
Get a flags value with all bits unset.
Sourcepub const fn all() -> SectionAttributes
pub const fn all() -> SectionAttributes
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<SectionAttributes>
pub const fn from_bits(bits: u32) -> Option<SectionAttributes>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> SectionAttributes
pub const fn from_bits_truncate(bits: u32) -> SectionAttributes
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> SectionAttributes
pub const fn from_bits_retain(bits: u32) -> SectionAttributes
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<SectionAttributes>
pub fn from_name(name: &str) -> Option<SectionAttributes>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: SectionAttributes) -> bool
pub const fn intersects(&self, other: SectionAttributes) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: SectionAttributes) -> bool
pub const fn contains(&self, other: SectionAttributes) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: SectionAttributes)
pub fn insert(&mut self, other: SectionAttributes)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: SectionAttributes)
pub fn remove(&mut self, other: SectionAttributes)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: SectionAttributes)
pub fn toggle(&mut self, other: SectionAttributes)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: SectionAttributes, value: bool)
pub fn set(&mut self, other: SectionAttributes, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: SectionAttributes) -> SectionAttributes
pub const fn intersection(self, other: SectionAttributes) -> SectionAttributes
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: SectionAttributes) -> SectionAttributes
pub const fn union(self, other: SectionAttributes) -> SectionAttributes
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: SectionAttributes) -> SectionAttributes
pub const fn difference(self, other: SectionAttributes) -> SectionAttributes
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(
self,
other: SectionAttributes,
) -> SectionAttributes
pub const fn symmetric_difference( self, other: SectionAttributes, ) -> SectionAttributes
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> SectionAttributes
pub const fn complement(self) -> SectionAttributes
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl SectionAttributes
impl SectionAttributes
Sourcepub const fn iter(&self) -> Iter<SectionAttributes> ⓘ
pub const fn iter(&self) -> Iter<SectionAttributes> ⓘ
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SectionAttributes> ⓘ
pub const fn iter_names(&self) -> IterNames<SectionAttributes> ⓘ
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.