pub struct VtableEntry {
pub name: Option<String>,
pub mangled_name: Option<String>,
pub va: Va,
pub size: u64,
pub slots: Vec<VtableSlot>,
}Expand description
The VtableEntry type.
Fields
name: Option<String>The name field.
mangled_name: Option<String>The mangled_name field.
va: VaThe va field.
size: u64The size field.
slots: Vec<VtableSlot>The slots field.
Implementations
Sourceimpl VtableEntry
impl VtableEntry
Sourcepub fn function_slots(&self) -> impl Iterator<Item = (usize, &VtableSlot)>
pub fn function_slots(&self) -> impl Iterator<Item = (usize, &VtableSlot)>
Return only the function slots (excluding offset-to-top and typeinfo header slots).
Sourcepub fn function_slot_count(&self) -> usize
pub fn function_slot_count(&self) -> usize
Number of function slots (excluding header slots).
Sourcepub fn find_slot_by_name(
&self,
method_name: &str,
) -> Option<(&VtableSlot, usize)>
pub fn find_slot_by_name( &self, method_name: &str, ) -> Option<(&VtableSlot, usize)>
Find a function slot by matching the demangled target name.
Returns the slot and its function-slot index (0-based, excluding header slots).
The match checks whether the demangled function name contains method_name.
Sourcepub fn function_slot_at(&self, index: usize) -> Option<&VtableSlot>
pub fn function_slot_at(&self, index: usize) -> Option<&VtableSlot>
Get a function slot by its 0-based function-slot index (excluding header slots like offset-to-top and typeinfo).